# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr

class FileTranscriptionSegmentResult(BaseModel):
    """
    FileTranscriptionSegmentResult
    """
    order: StrictInt = Field(default=..., description="Order of the segment in the transcription, starting from 1.")
    started_at: StrictStr = Field(default=..., description="Segment start time in the media file, in 'HH:MM:SS.mmm' format.")
    finished_at: StrictStr = Field(default=..., description="Segment end time in the media file, in 'HH:MM:SS.mmm' format.")
    transcription: StrictStr = Field(default=..., description="Transcribed text of the segment.")
    __properties = ["order", "started_at", "finished_at", "transcription"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FileTranscriptionSegmentResult:
        """Create an instance of FileTranscriptionSegmentResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FileTranscriptionSegmentResult:
        """Create an instance of FileTranscriptionSegmentResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FileTranscriptionSegmentResult.parse_obj(obj)

        _obj = FileTranscriptionSegmentResult.parse_obj({
            "order": obj.get("order"),
            "started_at": obj.get("started_at"),
            "finished_at": obj.get("finished_at"),
            "transcription": obj.get("transcription")
        })
        return _obj


